==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d2/dd0/structRoadVehicle.js <==
var structRoadVehicle =
[
    [ "RoadVehicle", "d2/dd0/structRoadVehicle.html#ae6e497de9d967bb6b7e07a1f313f6f96", null ],
    [ "~RoadVehicle", "d2/dd0/structRoadVehicle.html#a3b7f5f935346609d185448a4aaffcac3", null ],
    [ "Crash", "d2/dd0/structRoadVehicle.html#ad96241873409e58e112cd176402a5234", null ],
    [ "FindClosestDepot", "d2/dd0/structRoadVehicle.html#adb399bdf753e54723d56a64de33fb246", null ],
    [ "GetAccelerationStatus", "d2/dd0/structRoadVehicle.html#a5b4eae7a21a032b1462476d4e188ccd3", null ],
    [ "GetAccelerationType", "d2/dd0/structRoadVehicle.html#a8d76339c196b18e8afe1991216661c74", null ],
    [ "GetAirDrag", "d2/dd0/structRoadVehicle.html#a69d7d4725bc4a339088794b8d0963bc4", null ],
    [ "GetAirDragArea", "d2/dd0/structRoadVehicle.html#af727238cc2a7f65a6e58f63caa74a42a", null ],
    [ "GetCurrentMaxSpeed", "d2/dd0/structRoadVehicle.html#ae6a4c065ea9f5b7d849ee20d83f39048", null ],
    [ "GetCurrentSpeed", "d2/dd0/structRoadVehicle.html#a8ab7cba0c99a2802cfa46e4d85ab3861", null ],
    [ "GetDisplayImageWidth", "d2/dd0/structRoadVehicle.html#a917d4bd3a31b703028b2ca9c1ea88340", null ],
    [ "GetDisplayMaxSpeed", "d2/dd0/structRoadVehicle.html#a750bf0e102c98ce950a9a5679e29ac7b", null ],
    [ "GetDisplaySpeed", "d2/dd0/structRoadVehicle.html#ab384c8965ab99b13e72e8ec8e2f42716", null ],
    [ "GetExpenseType", "d2/dd0/structRoadVehicle.html#a40f1167abbd4ed392d865526f8cb172c", null ],
    [ "GetImage", "d2/dd0/structRoadVehicle.html#a580e2fad7aae603cf700b54407e20740", null ],
    [ "GetMaxTrackSpeed", "d2/dd0/structRoadVehicle.html#a7b7851cf3db1973bb0c45d914d16d7ea", null ],
    [ "GetOrderStationLocation", "d2/dd0/structRoadVehicle.html#a1406cb9c21782174d0b88a07d0642bfb", null ],
    [ "GetPower", "d2/dd0/structRoadVehicle.html#a92a8d1921532e15aa72035c5eff4a4fb", null ],
    [ "GetPoweredPartPower", "d2/dd0/structRoadVehicle.html#a48127ed3cde648ba5284a07d70840b34", null ],
    [ "GetRollingFriction", "d2/dd0/structRoadVehicle.html#aa3d0db10b6f9d2d8e182b67c5ece0b84", null ],
    [ "GetRunningCost", "d2/dd0/structRoadVehicle.html#a0a24bc0cfb1560d5c54b78f5a7e20dbc", null ],
    [ "GetSlopeSteepness", "d2/dd0/structRoadVehicle.html#af59a870522d5f09e1a0b170c866aa665", null ],
    [ "GetTractiveEffort", "d2/dd0/structRoadVehicle.html#acf2bb3c5a9ad135568102f169ec212d0", null ],
    [ "GetVehicleTrackdir", "d2/dd0/structRoadVehicle.html#a2e22db0ee3c1c1e90292e72d2e76179c", null ],
    [ "GetWeight", "d2/dd0/structRoadVehicle.html#aaaa51b126305a538f0170078cb5363ae", null ],
    [ "HasToUseGetSlopePixelZ", "d2/dd0/structRoadVehicle.html#abaa9a9aa225536f8f502f0bfe8428946", null ],
    [ "IsBus", "d2/dd0/structRoadVehicle.html#a6572d43204ce4dfbdb00bb9ba3422d7d", null ],
    [ "IsInDepot", "d2/dd0/structRoadVehicle.html#a2ba43ac7cc6c6ab78cfe2a7e314510f3", null ],
    [ "IsPrimaryVehicle", "d2/dd0/structRoadVehicle.html#a312da8c47446a0e0d65513712b0a86fc", null ],
    [ "MarkDirty", "d2/dd0/structRoadVehicle.html#a1d1b4c8e2d3fff5d102a55e11d7ccf25", null ],
    [ "OnNewDay", "d2/dd0/structRoadVehicle.html#a60ae16c900abf01397f8137523a5d6bf", null ],
    [ "Tick", "d2/dd0/structRoadVehicle.html#ab7711b3db8b69b54702a2c987412390f", null ],
    [ "TileMayHaveSlopedTrack", "d2/dd0/structRoadVehicle.html#ab2563f335fa34dcc41dd27fd9bda6d0a", null ],
    [ "UpdateDeltaXY", "d2/dd0/structRoadVehicle.html#a32ebe98f75196df39cbdf3a85518b256", null ],
    [ "UpdateSpeed", "d2/dd0/structRoadVehicle.html#abf5c319c5450cbf84365a4018de7722a", null ],
    [ "GroundVehicle< RoadVehicle, VEH_ROAD >", "d2/dd0/structRoadVehicle.html#a9343e7d8272be897a60122105d97f210", null ],
    [ "blocked_ctr", "d2/dd0/structRoadVehicle.html#aac4812a482264408f656b40a887cd3a8", null ],
    [ "compatible_roadtypes", "d2/dd0/structRoadVehicle.html#a55cce17deb1217f969b5026bdfda0c82", null ],
    [ "crashed_ctr", "d2/dd0/structRoadVehicle.html#a82713825e4367a0efa6867715030a486", null ],
    [ "frame", "d2/dd0/structRoadVehicle.html#a07b27c860247650b7ca6bd9dbb4fc502", null ],
    [ "overtaking", "d2/dd0/structRoadVehicle.html#afaaf245d7812a10da27208db95afe90c", null ],
    [ "overtaking_ctr", "d2/dd0/structRoadVehicle.html#a55e44b71f1f5345512b41726cd37ada1", null ],
    [ "reverse_ctr", "d2/dd0/structRoadVehicle.html#a223472fa3d582ad3fb3d9dca763a8819", null ],
    [ "roadtype", "d2/dd0/structRoadVehicle.html#abd68abab1e530fc0aff659534ee9b8f9", null ],
    [ "state", "d2/dd0/structRoadVehicle.html#a42ed7a417eb7ab9873a82cf4a5050b6a", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d2/dd0/structRoadVehicle.js <==
var structRoadVehicle =
[
    [ "RoadVehicle", "d2/dd0/structRoadVehicle.html#ae6e497de9d967bb6b7e07a1f313f6f96", null ],
    [ "~RoadVehicle", "d2/dd0/structRoadVehicle.html#a3b7f5f935346609d185448a4aaffcac3", null ],
    [ "Crash", "d2/dd0/structRoadVehicle.html#ad96241873409e58e112cd176402a5234", null ],
    [ "FindClosestDepot", "d2/dd0/structRoadVehicle.html#adb399bdf753e54723d56a64de33fb246", null ],
    [ "GetAccelerationStatus", "d2/dd0/structRoadVehicle.html#a5b4eae7a21a032b1462476d4e188ccd3", null ],
    [ "GetAccelerationType", "d2/dd0/structRoadVehicle.html#a8d76339c196b18e8afe1991216661c74", null ],
    [ "GetAirDrag", "d2/dd0/structRoadVehicle.html#a69d7d4725bc4a339088794b8d0963bc4", null ],
    [ "GetAirDragArea", "d2/dd0/structRoadVehicle.html#af727238cc2a7f65a6e58f63caa74a42a", null ],
    [ "GetCurrentMaxSpeed", "d2/dd0/structRoadVehicle.html#ae6a4c065ea9f5b7d849ee20d83f39048", null ],
    [ "GetCurrentSpeed", "d2/dd0/structRoadVehicle.html#a8ab7cba0c99a2802cfa46e4d85ab3861", null ],
    [ "GetDisplayImageWidth", "d2/dd0/structRoadVehicle.html#a452f0b124f66eea10fe47f4226caa9d6", null ],
    [ "GetDisplayMaxSpeed", "d2/dd0/structRoadVehicle.html#a750bf0e102c98ce950a9a5679e29ac7b", null ],
    [ "GetDisplaySpeed", "d2/dd0/structRoadVehicle.html#ab384c8965ab99b13e72e8ec8e2f42716", null ],
    [ "GetExpenseType", "d2/dd0/structRoadVehicle.html#a40f1167abbd4ed392d865526f8cb172c", null ],
    [ "GetImage", "d2/dd0/structRoadVehicle.html#a580e2fad7aae603cf700b54407e20740", null ],
    [ "GetMaxTrackSpeed", "d2/dd0/structRoadVehicle.html#a7b7851cf3db1973bb0c45d914d16d7ea", null ],
    [ "GetOrderStationLocation", "d2/dd0/structRoadVehicle.html#a1406cb9c21782174d0b88a07d0642bfb", null ],
    [ "GetPower", "d2/dd0/structRoadVehicle.html#a92a8d1921532e15aa72035c5eff4a4fb", null ],
    [ "GetPoweredPartPower", "d2/dd0/structRoadVehicle.html#a48127ed3cde648ba5284a07d70840b34", null ],
    [ "GetRollingFriction", "d2/dd0/structRoadVehicle.html#aa3d0db10b6f9d2d8e182b67c5ece0b84", null ],
    [ "GetRunningCost", "d2/dd0/structRoadVehicle.html#a0a24bc0cfb1560d5c54b78f5a7e20dbc", null ],
    [ "GetSlopeSteepness", "d2/dd0/structRoadVehicle.html#af59a870522d5f09e1a0b170c866aa665", null ],
    [ "GetTractiveEffort", "d2/dd0/structRoadVehicle.html#acf2bb3c5a9ad135568102f169ec212d0", null ],
    [ "GetVehicleTrackdir", "d2/dd0/structRoadVehicle.html#a2e22db0ee3c1c1e90292e72d2e76179c", null ],
    [ "GetWeight", "d2/dd0/structRoadVehicle.html#aaaa51b126305a538f0170078cb5363ae", null ],
    [ "HasToUseGetSlopePixelZ", "d2/dd0/structRoadVehicle.html#abaa9a9aa225536f8f502f0bfe8428946", null ],
    [ "IsBus", "d2/dd0/structRoadVehicle.html#a6572d43204ce4dfbdb00bb9ba3422d7d", null ],
    [ "IsInDepot", "d2/dd0/structRoadVehicle.html#a2ba43ac7cc6c6ab78cfe2a7e314510f3", null ],
    [ "IsPrimaryVehicle", "d2/dd0/structRoadVehicle.html#a312da8c47446a0e0d65513712b0a86fc", null ],
    [ "MarkDirty", "d2/dd0/structRoadVehicle.html#a1d1b4c8e2d3fff5d102a55e11d7ccf25", null ],
    [ "OnNewDay", "d2/dd0/structRoadVehicle.html#a60ae16c900abf01397f8137523a5d6bf", null ],
    [ "SetDestTile", "d2/dd0/structRoadVehicle.html#a294eb4288605fa776dca8d2eedd0c0da", null ],
    [ "Tick", "d2/dd0/structRoadVehicle.html#ab7711b3db8b69b54702a2c987412390f", null ],
    [ "TileMayHaveSlopedTrack", "d2/dd0/structRoadVehicle.html#ab2563f335fa34dcc41dd27fd9bda6d0a", null ],
    [ "UpdateDeltaXY", "d2/dd0/structRoadVehicle.html#a32ebe98f75196df39cbdf3a85518b256", null ],
    [ "UpdateSpeed", "d2/dd0/structRoadVehicle.html#abf5c319c5450cbf84365a4018de7722a", null ],
    [ "GroundVehicle< RoadVehicle, VEH_ROAD >", "d2/dd0/structRoadVehicle.html#a9343e7d8272be897a60122105d97f210", null ],
    [ "blocked_ctr", "d2/dd0/structRoadVehicle.html#aac4812a482264408f656b40a887cd3a8", null ],
    [ "compatible_roadtypes", "d2/dd0/structRoadVehicle.html#a55cce17deb1217f969b5026bdfda0c82", null ],
    [ "crashed_ctr", "d2/dd0/structRoadVehicle.html#a82713825e4367a0efa6867715030a486", null ],
    [ "frame", "d2/dd0/structRoadVehicle.html#a07b27c860247650b7ca6bd9dbb4fc502", null ],
    [ "overtaking", "d2/dd0/structRoadVehicle.html#afaaf245d7812a10da27208db95afe90c", null ],
    [ "overtaking_ctr", "d2/dd0/structRoadVehicle.html#a55e44b71f1f5345512b41726cd37ada1", null ],
    [ "path", "d2/dd0/structRoadVehicle.html#a9eb0761aabd88daf0386e727da180455", null ],
    [ "reverse_ctr", "d2/dd0/structRoadVehicle.html#a223472fa3d582ad3fb3d9dca763a8819", null ],
    [ "roadtype", "d2/dd0/structRoadVehicle.html#abd68abab1e530fc0aff659534ee9b8f9", null ],
    [ "state", "d2/dd0/structRoadVehicle.html#a42ed7a417eb7ab9873a82cf4a5050b6a", null ]
];
